;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "doom-modeline" "20251011.1051"
  "A minimal and modern mode-line."
  '((emacs       "25.1")
    (compat      "30.1.0.0")
    (nerd-icons  "0.1.0")
    (shrink-path "0.3.1"))
  :url "https://github.com/seagle0128/doom-modeline"
  :commit "abb1b4e0099fe2dc71b83bb555a4af7828ad033d"
  :revdesc "abb1b4e0099f"
  :keywords '("faces" "mode-line")
  :authors '(("Vincent Zhang" . "seagle0128@gmail.com"))
  :maintainers '(("Vincent Zhang" . "seagle0128@gmail.com")))
